<?php
/**
 * Parse RSS feed from provided URL, return the posts within as an array
 *
 * @param string $url - the URL of the RSS feed to retrieve
 * @param int $limit - how many posts to retrieve
 * @return array - array of posts, or empty array if none are found
 */
function efm_news_get_feed($url, $limit=5) {
    $rss = simplexml_load_file($url); //loading the document
    $out = array();
    if(!empty($rss->channel->item)) {
        $count = 0;
        foreach($rss->channel->item as $post) {
            $count++;
            if($count > $limit) {
                break;
            }
            $out[] = array(
                'title' => (string) $post->title,
                'link' => (string) $post->link.'?utm_source=EuropaFMNewsPlugin&utm_medium=link',
                'date' => (string) strtotime($post->pubDate), /* date in UNIX time format, can be used with date() */
                'author' => (string) $post->creator,
                'category' => (string) $post->category,
                'content' => (string) str_replace('[...]','',$post->description)
            );
        }
    }
    return $out;
}

//Output the default CSS for the module.
//Because there are only a few rules we decided to inline it, to save a HTTP request.
function efm_news_get_css() {
    $out = '<style>';
    $out .= '
    .efm-news .clearfix:before, .efm-news .clearfix:after { content: " "; display: table; }
    .efm-news .clearfix:after { clear: both; }
    .efm-news { display:block;margin-bottom:20px;}
    .efm-news-widget-title { font-size:1.2em;font-weight:bold;margin-bottom:10px;border-left:4px solid #E30613;text-transform:uppercase;padding-left:5px; }
    .efm-news-post { margin-bottom:15px; }
    .efm-news-post .post-image { float:left;margin-right:10px; }
    .efm-news-post .post-image img { width:100px;height:100px; object-fit:cover;object-position:center; } 
    .efm-news-title { font-weight:bold;margin-bottom: 10px; }
    .efm-news-date { font-size: 0.8em; font-weight:bold; }
    .efm-news .powered-by { font-size:0.7em }
    .efm-news .powered-by img { vertical-align:middle; }
    .efm-news-excerpt {}
    .efm-news.red { background-color:#E30613;color:#fff }
    .efm-news.red a { color:#fff }
    .efm-news.red { padding:15px; }
    .efm-news.red .efm-news-widget-title { border-left:none;padding-left:0; }
    ';
    $out .= '</style>';
    return $out;
}


//render the HTML based on attributes provided. This function is used by the shortcode,widget and visual composer module
//this function can be used in your code to get the HTML. Use the default options as a template for the $attributes param
function efm_news_render($attributes) {
    //set default values for all options
    $options = shortcode_atts( array(
        'title' => '',
        'title-container' => 'div',
        'source' => 'stiri',
        'limit' => 5,
        'date-format' => 'd/m/Y',
        'hide-date' => 1,
        'hide-excerpt' => 0,
        'hide-credits' => 0,
        'hide-images' => 0,
        'use-css' => 1,
        'style' => 'default',
        'font-size' => 16,
        'excerpt-length' => 230,
    ), $attributes );


    $out = ''; //HTML code will be added to this along the way
    $efm_news_sources = efm_news_get_sources(); //a list of the various newsfeeds available, can be found in options.php in plugin's root folder

    //get posts from source based on options selected
    if(array_key_exists($options['source'],$efm_news_sources)) {
        $posts = efm_news_get_feed($efm_news_sources[$options['source']]['url'],$options['limit']);
    } else {
        $out .= '<div class="efm-news notification">'.__('EuropaFM News: Invalid parameter value for source. Please use one of the following:','efm-news').' '.array_keys($sources).'</div>';
    }

    //iterate over posts and  built HTML
    if(!empty($posts)) {
        if(empty($options['title'])) {
            $options['title'] = str_replace('-',' ',$efm_news_sources[$options['source']]['title']);
        }
        $out .= efm_news_get_css();
        $out .= '<div class="efm-news '.$options['style'].'" style="font-size:'.$options['font-size'].'px">';
        $out .= '<div class="efm-news-widget-title">'.$options['title'].'</div>';

        foreach($posts as $post){
            $image_end = (strpos($post['content'],'</span>')+7);
            $post_content = str_split($post['content'],$image_end);
            $post_image = $post_content[0];
            $post_content = $post_content[1];

            //excerpt length, uses mb function to prevent display errors when cutting next to romanian characters
            mb_internal_encoding("UTF-8");
            if(strlen($post_content) > $options['excerpt-length']) {
                $post_content = mb_substr($post_content,0,$options['excerpt-length']);
            }

            $out .= '<div class="efm-news-post clearfix">';
            $out .= '<'.$options['title-container'].' class="efm-news-title"><a href="'.$post['link'].'" target="_blank">'.$post['title'].'</a></'.$options['title-container'].'>';
            if(empty($options['hide-excerpt'])) {
                $out .= '<div class="efm-news-excerpt">';
                if(empty($options['hide-images'])) {
                    $out .= '<a href="'.$post['link'].'">'.$post_image.'</a>';
                }
                $out .= $post_content.'[...]</div>';
            }
            if(empty($options['hide-date'])) {
                $out .= '<div class="efm-news-date">'.date($options['date-format'],$post['date']).'</div>';
            }
            $out .= '</div>';
        }

        if(empty($options['hide-credits'])) {
            $out .= '<a href="https://www.europafm.ro/?utm_source=EuropaFMNewsPlugin&utm_medium=link" class="powered-by" title="Powered by EuropaFM.ro">';
            if($options['style'] == 'red') {
                $out .= '<img src="' . EFM_NEWS_PLUGIN_URL. '/res/efm-logo-white.png" width="80" height="38" />';
            } else {
                $out .= '<img src="' . EFM_NEWS_PLUGIN_URL . '/res/efm-logo.png" width="80" height="38" />';
            }
            $out .= '</a>';
        }

        $out .= '</div>';
    }
    return $out;
}